==> maverik-5.4.tar.gz: maverik-5.4/src/extras/VRML97/vrmlnodetype.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2000 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Computer Science Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_cvcomp.h"

/******************************************************************
*
*	VRML library for C++
*
*	Copyright (C) Satoshi Konno 1996-1997
*
*	File:	vrmlnodetype.h
*
******************************************************************/

#ifndef _VRMLNODETYPE_H_
#define _VRMLNODETYPE_H_

enum {
VRML_NODETYPE_NONE,
VRML_NODETYPE_ROOT,
VRML_NODETYPE_ANCHOR,
VRML_NODETYPE_ANCHOR_PARAMETER,
VRML_NODETYPE_ANCHOR_URL,
VRML_NODETYPE_APPEARANCE,
VRML_NODETYPE_IMAGETEXTURE,
VRML_NODETYPE_IMAGETEXTURE_URL,
VRML_NODETYPE_MOVIETEXTURE,
VRML_NODETYPE_MOVIETEXTURE_URL,
VRML_NODETYPE_PIXELTEXTURE,
VRML_NODETYPE_PIXELTEXTURE_IMAGE,
VRML_NODETYPE_TEXTURETRANSFORM,
VRML_NODETYPE_AUDIOCLIP,
VRML_NODETYPE_AUDIOCLIP_URL,
VRML_NODETYPE_TRANSFORM,
VRML_NODETYPE_GROUP,
VRML_NODETYPE_BILLBOARD,
VRML_NODETYPE_BACKGROUND,
VRML_NODETYPE_BACKGROUND_BACKURL,
VRML_NODETYPE_BACKGROUND_FRONTURL,
VRML_NODETYPE_BACKGROUND_LEFTURL,
VRML_NODETYPE_BACKGROUND_RIGHTURL,
VRML_NODETYPE_BACKGROUND_BOTTOMURL,
VRML_NODETYPE_BACKGROUND_TOPURL,
VRML_NODETYPE_BACKGROUND_SKYCOLOR,
VRML_NODETYPE_BACKGROUND_GROUNDCOLOR,
VRML_NODETYPE_BACKGROUND_SKYANGLE,
VRML_NODETYPE_BACKGROUND_GROUNDANGLE,
VRML_NODETYPE_BOX,
VRML_NODETYPE_COLLISION,
VRML_NODETYPE_COLLISION_PROXY,
VRML_NODETYPE_COLOR,
VRML_NODETYPE_COLORINTERPOLATOR,
VRML_NODETYPE_CONE,
VRML_NODETYPE_COORDINATEINTERPOLATOR,
VRML_NODETYPE_CYLINDER,
VRML_NODETYPE_CYLINDERSENSOR,
VRML_NODETYPE_DIRECTIONALLIGHT,
VRML_NODETYPE_ELEVATIONGRID,
VRML_NODETYPE_ELEVATIONGRID_HEIGHT,
VRML_NODETYPE_EXTRUSION,
VRML_NODETYPE_EXTRUSION_CROSSSECTION,
VRML_NODETYPE_EXTRUSION_ORIENTATION,
VRML_NODETYPE_EXTRUSION_SCALE,
VRML_NODETYPE_EXTRUSION_SPINE,
VRML_NODETYPE_FOG,
VRML_NODETYPE_FONTSTYLE,
VRML_NODETYPE_FONTSTYLE_JUSTIFY,
VRML_NODETYPE_INLINE,
VRML_NODETYPE_INLINE_URL,
VRML_NODETYPE_INTERPOLATOR_KEY,
VRML_NODETYPE_INTERPOLATOR_KEYVALUE,
VRML_NODETYPE_LOD,
VRML_NODETYPE_LOD_RANGE,
VRML_NODETYPE_LOD_LEVEL,
VRML_NODETYPE_NAVIGATIONINFO,
VRML_NODETYPE_NAVIGATIONINFO_AVATARSIZE,
VRML_NODETYPE_NAVIGATIONINFO_TYPE,
VRML_NODETYPE_NORMALINTERPOLATOR,
VRML_NODETYPE_ORIENTATIONINTERPOLATOR,
VRML_NODETYPE_POSITIONINTERPOLATOR,
VRML_NODETYPE_PLANESENSOR,
VRML_NODETYPE_PROXIMITYSENSOR,
VRML_NODETYPE_SCALARINTERPOLATOR,
VRML_NODETYPE_SCRIPT,
VRML_NODETYPE_SCRIPT_URL,
VRML_NODETYPE_SOUND,
VRML_NODETYPE_SPHERESENSOR,
VRML_NODETYPE_TIMESENSOR,
VRML_NODETYPE_TOUCHSENSOR,
VRML_NODETYPE_VISIBILITYSENSOR,
VRML_NODETYPE_SPHERE,
VRML_NODETYPE_SWITCH,
VRML_NODETYPE_SWITCH_CHOICE,
VRML_NODETYPE_TEXT,
VRML_NODETYPE_TEXT_STRING,
VRML_NODETYPE_TEXT_LENGTH,
VRML_NODETYPE_TRANSLATION,
VRML_NODETYPE_CHILDREN,
VRML_NODETYPE_SHAPE,
VRML_NODETYPE_WORLDINFO,
VRML_NODETYPE_WORLDINFO_INFO,
VRML_NODETYPE_VIEWPOINT,
VRML_NODETYPE_COORDINATE,
VRML_NODETYPE_COORDINATE_INDEX,
VRML_NODETYPE_POINTLIGHT,
VRML_NODETYPE_POINTSET,
VRML_NODETYPE_CUBE,
VRML_NODETYPE_INDEXEDFACESET,
VRML_NODETYPE_INDEXEDLINESET,
VRML_NODETYPE_MATERIAL,
VRML_NODETYPE_TEXTURECOODINATE,
VRML_NODETYPE_SPOTLIGHT,
VRML_NODETYPE_NORMAL,
VRML_NODETYPE_NORMAL_INDEX,
VRML_NODETYPE_TEXTURECOODINATE_INDEX,
VRML_NODETYPE_COLOR_INDEX,
};

#endif //JMC

==> maverik-6.1.tar.gz: maverik-6.1/src/extras/VRML97/vrmlnodetype.h <==
/*
 GNU Maverik - a system for managing display and interaction in 
               Virtual Environment applications.
 Copyright (C) 1999-2001 Advanced Interfaces Group

 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA


 The authors can be contacted via:
 www   - http://aig.cs.man.ac.uk
 email - maverik@aig.cs.man.ac.uk
 mail  - Advanced Interfaces Group, Room 2.94, Kilburn Building, 
         University of Manchester, Manchester, M13 9PL, UK
*/


#include "mavlib_cvcomp.h"

/******************************************************************
*
*	VRML library for C++
*
*	Copyright (C) Satoshi Konno 1996-1997
*
*	File:	vrmlnodetype.h
*
******************************************************************/

#ifndef _VRMLNODETYPE_H_
#define _VRMLNODETYPE_H_

enum {
VRML_NODETYPE_NONE,
VRML_NODETYPE_ROOT,
VRML_NODETYPE_ANCHOR,
VRML_NODETYPE_ANCHOR_PARAMETER,
VRML_NODETYPE_ANCHOR_URL,
VRML_NODETYPE_APPEARANCE,
VRML_NODETYPE_IMAGETEXTURE,
VRML_NODETYPE_IMAGETEXTURE_URL,
VRML_NODETYPE_MOVIETEXTURE,
VRML_NODETYPE_MOVIETEXTURE_URL,
VRML_NODETYPE_PIXELTEXTURE,
VRML_NODETYPE_PIXELTEXTURE_IMAGE,
VRML_NODETYPE_TEXTURETRANSFORM,
VRML_NODETYPE_AUDIOCLIP,
VRML_NODETYPE_AUDIOCLIP_URL,
VRML_NODETYPE_TRANSFORM,
VRML_NODETYPE_GROUP,
VRML_NODETYPE_BILLBOARD,
VRML_NODETYPE_BACKGROUND,
VRML_NODETYPE_BACKGROUND_BACKURL,
VRML_NODETYPE_BACKGROUND_FRONTURL,
VRML_NODETYPE_BACKGROUND_LEFTURL,
VRML_NODETYPE_BACKGROUND_RIGHTURL,
VRML_NODETYPE_BACKGROUND_BOTTOMURL,
VRML_NODETYPE_BACKGROUND_TOPURL,
VRML_NODETYPE_BACKGROUND_SKYCOLOR,
VRML_NODETYPE_BACKGROUND_GROUNDCOLOR,
VRML_NODETYPE_BACKGROUND_SKYANGLE,
VRML_NODETYPE_BACKGROUND_GROUNDANGLE,
VRML_NODETYPE_BOX,
VRML_NODETYPE_COLLISION,
VRML_NODETYPE_COLLISION_PROXY,
VRML_NODETYPE_COLOR,
VRML_NODETYPE_COLORINTERPOLATOR,
VRML_NODETYPE_CONE,
VRML_NODETYPE_COORDINATEINTERPOLATOR,
VRML_NODETYPE_CYLINDER,
VRML_NODETYPE_CYLINDERSENSOR,
VRML_NODETYPE_DIRECTIONALLIGHT,
VRML_NODETYPE_ELEVATIONGRID,
VRML_NODETYPE_ELEVATIONGRID_HEIGHT,
VRML_NODETYPE_EXTRUSION,
VRML_NODETYPE_EXTRUSION_CROSSSECTION,
VRML_NODETYPE_EXTRUSION_ORIENTATION,
VRML_NODETYPE_EXTRUSION_SCALE,
VRML_NODETYPE_EXTRUSION_SPINE,
VRML_NODETYPE_FOG,
VRML_NODETYPE_FONTSTYLE,
VRML_NODETYPE_FONTSTYLE_JUSTIFY,
VRML_NODETYPE_INLINE,
VRML_NODETYPE_INLINE_URL,
VRML_NODETYPE_INTERPOLATOR_KEY,
VRML_NODETYPE_INTERPOLATOR_KEYVALUE,
VRML_NODETYPE_LOD,
VRML_NODETYPE_LOD_RANGE,
VRML_NODETYPE_LOD_LEVEL,
VRML_NODETYPE_NAVIGATIONINFO,
VRML_NODETYPE_NAVIGATIONINFO_AVATARSIZE,
VRML_NODETYPE_NAVIGATIONINFO_TYPE,
VRML_NODETYPE_NORMALINTERPOLATOR,
VRML_NODETYPE_ORIENTATIONINTERPOLATOR,
VRML_NODETYPE_POSITIONINTERPOLATOR,
VRML_NODETYPE_PLANESENSOR,
VRML_NODETYPE_PROXIMITYSENSOR,
VRML_NODETYPE_SCALARINTERPOLATOR,
VRML_NODETYPE_SCRIPT,
VRML_NODETYPE_SCRIPT_URL,
VRML_NODETYPE_SOUND,
VRML_NODETYPE_SPHERESENSOR,
VRML_NODETYPE_TIMESENSOR,
VRML_NODETYPE_TOUCHSENSOR,
VRML_NODETYPE_VISIBILITYSENSOR,
VRML_NODETYPE_SPHERE,
VRML_NODETYPE_SWITCH,
VRML_NODETYPE_SWITCH_CHOICE,
VRML_NODETYPE_TEXT,
VRML_NODETYPE_TEXT_STRING,
VRML_NODETYPE_TEXT_LENGTH,
VRML_NODETYPE_TRANSLATION,
VRML_NODETYPE_CHILDREN,
VRML_NODETYPE_SHAPE,
VRML_NODETYPE_WORLDINFO,
VRML_NODETYPE_WORLDINFO_INFO,
VRML_NODETYPE_VIEWPOINT,
VRML_NODETYPE_COORDINATE,
VRML_NODETYPE_COORDINATE_INDEX,
VRML_NODETYPE_POINTLIGHT,
VRML_NODETYPE_POINTSET,
VRML_NODETYPE_CUBE,
VRML_NODETYPE_INDEXEDFACESET,
VRML_NODETYPE_INDEXEDLINESET,
VRML_NODETYPE_MATERIAL,
VRML_NODETYPE_TEXTURECOODINATE,
VRML_NODETYPE_SPOTLIGHT,
VRML_NODETYPE_NORMAL,
VRML_NODETYPE_NORMAL_INDEX,
VRML_NODETYPE_TEXTURECOODINATE_INDEX,
VRML_NODETYPE_COLOR_INDEX,
};

#endif //JMC
